class Uom:
    """

    Sourced from: https://github.com/home-assistant/core/blob/03b1c7ad1deb4b9494df01b27ef8e1d7dfe179ba/homeassistant/const.py#L489C1-L489C1

    """
    POWER_WATT: str = "W"
    POWER_KILO_WATT: str = "kW"

    VOLT: str = "V"

    ENERGY_WATT_HOUR: str = "Wh"
    ENERGY_KILO_WATT_HOUR: str = "kWh"

    ELECTRICAL_CURRENT_AMPERE: str = "A"
    ELECTRICAL_VOLT_AMPERE: str = "VA"

    DEGREE: str = "°"

    CURRENCY_EURO: str = "€"
    CURRENCY_DOLLAR: str = "$"
    CURRENCY_CENT: str = "¢"

    TEMP_CELSIUS: str = "°C"
    TEMP_FAHRENHEIT: str = "°F"
    TEMP_KELVIN: str = "K"

    TIME_MICROSECONDS: str = "μs"
    TIME_MILLISECONDS: str = "ms"
    TIME_SECONDS: str = "s"
    TIME_MINUTES: str = "min"
    TIME_HOURS: str = "h"
    TIME_DAYS: str = "d"
    TIME_WEEKS: str = "w"
    TIME_MONTHS: str = "m"
    TIME_YEARS: str = "y"

    LENGTH_MILLIMETERS: str = "mm"
    LENGTH_CENTIMETERS: str = "cm"
    LENGTH_METERS: str = "m"
    LENGTH_KILOMETERS: str = "km"

    LENGTH_INCHES: str = "in"
    LENGTH_FEET: str = "ft"
    LENGTH_YARD: str = "yd"
    LENGTH_MILES: str = "mi"

    FREQUENCY_HERTZ: str = "Hz"
    FREQUENCY_GIGAHERTZ: str = "GHz"

    PRESSURE_PA: str = "Pa"
    PRESSURE_HPA: str = "hPa"
    PRESSURE_BAR: str = "bar"
    PRESSURE_MBAR: str = "mbar"
    PRESSURE_INHG: str = "inHg"
    PRESSURE_PSI: str = "psi"

    VOLUME_LITERS: str = "L"
    VOLUME_MILLILITERS: str = "mL"
    VOLUME_CUBIC_METERS: str = "m³"
    VOLUME_CUBIC_FEET: str = "ft³"

    VOLUME_GALLONS: str = "gal"
    VOLUME_FLUID_OUNCE: str = "fl. oz."

    VOLUME_FLOW_RATE_CUBIC_METERS_PER_HOUR: str = "m³/h"
    VOLUME_FLOW_RATE_CUBIC_FEET_PER_MINUTE: str = "ft³/m"

    AREA_SQUARE_METERS: str = "m²"

    MASS_GRAMS: str = "g"
    MASS_KILOGRAMS: str = "kg"
    MASS_MILLIGRAMS: str = "mg"
    MASS_MICROGRAMS: str = "µg"

    MASS_OUNCES: str = "oz"
    MASS_POUNDS: str = "lb"

    CONDUCTIVITY: str = "µS/cm"

    LIGHT_LUX: str = "lx"

    UV_INDEX: str = "UV index"

    PERCENTAGE: str = "%"

    IRRADIATION_WATTS_PER_SQUARE_METER: str = "W/m²"

    PRECIPITATION_MILLIMETERS_PER_HOUR: str = "mm/h"

    CONCENTRATION_MICROGRAMS_PER_CUBIC_METER: str = "µg/m³"
    CONCENTRATION_MILLIGRAMS_PER_CUBIC_METER: str = "mg/m³"
    CONCENTRATION_PARTS_PER_CUBIC_METER: str = "p/m³"
    CONCENTRATION_PARTS_PER_MILLION: str = "ppm"
    CONCENTRATION_PARTS_PER_BILLION: str = "ppb"

    SPEED_MILLIMETERS_PER_DAY: str = "mm/d"
    SPEED_INCHES_PER_DAY: str = "in/d"
    SPEED_METERS_PER_SECOND: str = "m/s"
    SPEED_INCHES_PER_HOUR: str = "in/h"
    SPEED_KILOMETERS_PER_HOUR: str = "km/h"
    SPEED_MILES_PER_HOUR: str = "mph"

    SIGNAL_STRENGTH_DECIBELS: str = "dB"
    SIGNAL_STRENGTH_DECIBELS_MILLIWATT: str = "dBm"

    DATA_BITS: str = "bit"
    DATA_KILOBITS: str = "kbit"
    DATA_MEGABITS: str = "Mbit"
    DATA_GIGABITS: str = "Gbit"
    DATA_BYTES: str = "B"
    DATA_KILOBYTES: str = "kB"
    DATA_MEGABYTES: str = "MB"
    DATA_GIGABYTES: str = "GB"
    DATA_TERABYTES: str = "TB"
    DATA_PETABYTES: str = "PB"
    DATA_EXABYTES: str = "EB"
    DATA_ZETTABYTES: str = "ZB"
    DATA_YOTTABYTES: str = "YB"
    DATA_KIBIBYTES: str = "KiB"
    DATA_MEBIBYTES: str = "MiB"
    DATA_GIBIBYTES: str = "GiB"
    DATA_TEBIBYTES: str = "TiB"
    DATA_PEBIBYTES: str = "PiB"
    DATA_EXBIBYTES: str = "EiB"
    DATA_ZEBIBYTES: str = "ZiB"
    DATA_YOBIBYTES: str = "YiB"
    DATA_RATE_BITS_PER_SECOND: str = "bit/s"
    DATA_RATE_KILOBITS_PER_SECOND: str = "kbit/s"
    DATA_RATE_MEGABITS_PER_SECOND: str = "Mbit/s"
    DATA_RATE_GIGABITS_PER_SECOND: str = "Gbit/s"
    DATA_RATE_BYTES_PER_SECOND: str = "B/s"
    DATA_RATE_KILOBYTES_PER_SECOND: str = "kB/s"
    DATA_RATE_MEGABYTES_PER_SECOND: str = "MB/s"
    DATA_RATE_GIGABYTES_PER_SECOND: str = "GB/s"
    DATA_RATE_KIBIBYTES_PER_SECOND: str = "KiB/s"
    DATA_RATE_MEBIBYTES_PER_SECOND: str = "MiB/s"
    DATA_RATE_GIBIBYTES_PER_SECOND: str = "GiB/s"
